@@ -20,6 +20,9 @@ except ImportError:
 import sys
 
 use_RTLD_GLOBAL = hasattr(sys, "getdlopenflags")
+
+use_RTLD_GLOBAL = False # testing whether this fixes crashes on Ubuntu 10.04/amd64 without causing other problems on any platform.
+
 if use_RTLD_GLOBAL:
     try:
         from ctypes import RTLD_GLOBAL as RTLD_GLOBAL_FROM_CTYPES
@@ -38,6 +41,7 @@ try:
         sys.setdlopenflags(flags|RTLD_GLOBAL)
 
     import _pycryptopp # all that work for one little import
+    __doc__ = _pycryptopp.__doc__
 
 finally:
     if use_RTLD_GLOBAL:
@@ -53,4 +57,4 @@ def _import_my_names(thismodule, prefix):
 import publickey, hash, cipher
 
 quiet_pyflakes=[__version__, publickey, hash, cipher, _pycryptopp]
-del sys, quiet_pyflakes
+del sys, quiet_pyflakes, _import_my_names, use_RTLD_GLOBAL
